@@ -17,8 +17,9 @@ for v in 'PYTHONPATH', 'srcdir', 'LINK_GRAMMAR_DATA':
 #===
 
 
-from linkgrammar import Sentence, Linkage, ParseOptions, Link, Dictionary, \
-                        Clinkgrammar as clg
+from linkgrammar import (Sentence, Linkage, ParseOptions, Link, Dictionary,
+                         LG_DictionaryError, LG_TimerExhausted,
+                         Clinkgrammar as clg)
 
 
 # Show the location and version of the bindings modules
@@ -30,6 +31,8 @@ for module in 'linkgrammar', '_clinkgrammar', 'lg_testutils':
         print()
     else:
         print("Warning: Module", module,  "not loaded.")
+
+sys.stdout.flush()
 #===
 
 def setUpModule():
@@ -53,6 +56,10 @@ class AAALinkTestCase(unittest.TestCase):
         self.assertEqual(str(Link(None, 0, 'Left','Link','Link*','Right')),
                          u'Left-Link-Link*-Right')
 
+class AADictionaryTestCase(unittest.TestCase):
+    def test_open_nonexistent_dictionary(self):
+        self.assertRaises(LG_DictionaryError, Dictionary, 'No such language')
+
 class BParseOptionsTestCase(unittest.TestCase):
     def test_setting_verbosity(self):
         po = ParseOptions()
@@ -293,6 +300,13 @@ class DBasicParsingTestCase(unittest.TestCase):
         linkage = self.parse_sent("This is a _regex_ive regex test")[0]
         self.assertEqual(linkage.word(4), '_regex_ive[!].a')
 
+    def test_timer_exhausted_exception(self):
+        self.po = ParseOptions(max_parse_time=1)
+        self.assertRaises(LG_TimerExhausted,
+                          self.parse_sent,
+                          "This should take more than one second to parse! " * 20,
+                          self.po)
+
 class ESATsolverTestCase(unittest.TestCase):
     def setUp(self):
         self.d, self.po = Dictionary(lang='en'), ParseOptions()
