@@ -33,7 +33,13 @@
 #ifndef _API_STRUCTURESH_
 #define _API_STRUCTURESH_
 
-#include <locale.h>                /* for locale_t */
+/* For locale_t */
+#ifdef HAVE_LOCALE_T_IN_LOCALE_H
+#include <locale.h>
+#endif /* HAVE_LOCALE_T_IN_LOCALE_H */
+#ifdef HAVE_LOCALE_T_IN_XLOCALE_H
+#include <xlocale.h>
+#endif /* HAVE_LOCALE_T_IN_XLOCALE_H */
 
 #include "api-types.h"
 #include "dict-structures.h"
@@ -63,13 +69,13 @@ struct Resources_s
 struct Parse_Options_s
 {
 	/* General options */
-	int verbosity;         /* Level of detail to give about the computation 0 */
+	short verbosity;       /* Level of detail to give about the computation 0 */
 	char * debug;          /* comma-separated function names to debug "" */
 	char * test;           /* comma-separated features to test "" */
 	Resources resources;   /* For deciding when to abort the parsing */
 
 	/* Options governing the tokenizer (sentence-splitter) */
-	int use_spell_guess;  /* Perform spell-guessing of unknown words. */
+	short use_spell_guess;  /* Perform spell-guessing of unknown words. */
 
 	/* Choice of the parser to use */
 	bool use_sat_solver;   /* Use the Boolean SAT based parser */
@@ -77,8 +83,8 @@ struct Parse_Options_s
 
 	/* Options governing the parser internals operation */
 	double disjunct_cost;  /* Max disjunct cost to allow */
-	int min_null_count;    /* The minimum number of null links to allow */
-	int max_null_count;    /* The maximum number of null links to allow */
+	short min_null_count;  /* The minimum number of null links to allow */
+	short max_null_count;  /* The maximum number of null links to allow */
 	bool islands_ok;       /* If TRUE, then linkages with islands
 	                          (separate component of the link graph)
 	                          will be generated (default=FALSE) */
@@ -89,6 +95,7 @@ struct Parse_Options_s
 	bool repeatable_rand;  /* Reset rand number gen after every parse. */
 
 	/* Options governing post-processing */
+	bool perform_pp_prune; /* Perform post-processing-based pruning */
 	size_t twopass_length; /* min sent length for two-pass post processing */
 	Cost_Model cost_model; /* For sorting linkages in post_processing */
 
@@ -118,14 +125,14 @@ struct Exp_list_s
 
 struct Dictionary_s
 {
-	Dict_node *     root;
-	Regex_node *    regex_root;
-	const char *    name;
-	const char *    lang;
-	const char *    version;
-	const char *    locale;
-	locale_t        locale_t;
-	int             num_entries;
+	Dict_node *  root;
+	Regex_node * regex_root;
+	const char * name;
+	const char * lang;
+	const char * version;
+	const char * locale;    /* Locale name */
+	locale_t     lctype;    /* Locale argument for the *_l() functions */
+	int          num_entries;
 
 	bool         use_unknown_word;
 	bool         unknown_word_defined;
@@ -290,8 +297,8 @@ struct PP_data_s
 	size_t vlength;                 /* Length of visited array */
 };
 
-/* A new Postprocessor stuct is alloe for each sentence. It contains
- * sentence-specific post-processing nformation.
+/* A new Postprocessor struct is alloc'ed for each sentence. It contains
+ * sentence-specific post-processing information.
  */
 struct Postprocessor_s
 {
