@@ -15,11 +15,12 @@
 #include "structures.h"
 
 void build_sentence_disjuncts(Sentence sent, double cost_cutoff);
-X_node *   build_word_expressions(Dictionary dict, const char *);
+X_node *   build_word_expressions(Sentence, const Gword *, const char *);
 Disjunct * build_disjuncts_for_exp(Exp*, const char*, double cost_cutoff);
 
 unsigned int count_disjunct_for_dict_node(Dict_node *dn);
 
 #ifdef DEBUG
 void prt_exp(Exp *, int);
+void prt_exp_mem(Exp *, int);
 #endif
