@@ -21,6 +21,8 @@
 #include "print-util.h"
 #include "string-set.h"
 
+#define D_CONST 8 /* debug level for this file */
+
 #define OPEN_BRACKET '['
 #define CLOSE_BRACKET ']'
 
@@ -66,7 +68,14 @@ struct CNode_s
 
 static inline bool uppercompare(const char * s, const char * t)
 {
+#if 0  /* Non-ASCII definition are not supported.  */
 	return (false == utf8_upper_match(s,t));
+#endif
+	while (isupper(*s) || isupper(*t))
+	{
+		if (*s++ != *t++) return true;
+	}
+	return false;
 }
 
 /**
@@ -97,7 +106,6 @@ static void adjust_for_right_comma(con_context_t *ctxt, Linkage linkage, int c)
 static void print_constituent(con_context_t *ctxt, Linkage linkage, int c)
 {
 	size_t w;
-	if (verbosity < 2) return;
 
 	printf("  c %2d %4s [%c] (%2zu-%2zu): ",
 		   c, ctxt->constituent[c].type, ctxt->constituent[c].domain_type,
@@ -208,7 +216,7 @@ static int gen_comp(con_context_t *ctxt, Linkage linkage,
 		if (!(strcmp(ctxt->constituent[c1].type, ctype1)==0))
 			continue;
 
-		if (verbosity >= 2)
+		if (debug_level(D_CONST))
 			printf("Generating complement constituent for c %d of type %s\n",
 				   c1, ctype1);
 		done = false;
@@ -259,7 +267,7 @@ static int gen_comp(con_context_t *ctxt, Linkage linkage,
 					ctxt->constituent[c].domain_type = 'x';
 					ctxt->constituent[c].start_link =
 						string_set_add("XX", ctxt->phrase_ss);
-					if (verbosity >= 2)
+					if (debug_level(D_CONST))
 					{
 						printf("Larger c found: c %d (%s); ",
 							   c2, ctype2);
@@ -272,7 +280,7 @@ static int gen_comp(con_context_t *ctxt, Linkage linkage,
 				}
 			}
 		}
-		if (verbosity >= 2)
+		if (debug_level(D_CONST))
 		{
 			if (done == false)
 				printf("No constituent added, because no larger %s " \
@@ -321,9 +329,11 @@ static void adjust_subordinate_clauses(con_context_t *ctxt, Linkage linkage,
 						w = ctxt->constituent[c].left - 1;
 						ctxt->constituent[c2].right = w;
 
-						if (verbosity >= 2)
+						if (debug_level(D_CONST))
+						{
 							printf("Adjusting constituent %d:\n", c2);
-						print_constituent(ctxt, linkage, c2);
+							print_constituent(ctxt, linkage, c2);
+						}
 					}
 				}
 			}
@@ -435,7 +445,7 @@ static int new_style_conjunctions(con_context_t *ctxt, Linkage linkage, int numc
 	for (c = 0; c < numcon_total; c++)
 	{
 		constituent_t *ct = &ctxt->constituent[c];
-		lgdebug(3, "ola %d valid=%d %s start=%s lr=%zu %zu\n", c,
+		lgdebug(6, "ola %d valid=%d %s start=%s lr=%zu %zu\n", c,
 			ct->valid, ct->type, ct->start_link, ct->left, ct->right);
 	}
 #endif
@@ -578,9 +588,11 @@ static int last_minute_fixes(con_context_t *ctxt, Linkage linkage, int numcon_to
 		ctxt->constituent[c].valid = true;
 		ctxt->constituent[c].domain_type = 'x';
 		numcon_total++;
-		if (verbosity >= 2)
+		if (debug_level(D_CONST))
+		{
 			printf("Adding global sentence constituent:\n");
-		print_constituent(ctxt, linkage, c);
+			print_constituent(ctxt, linkage, c);
+		}
 	}
 
 	return numcon_total;
@@ -821,12 +833,13 @@ static int read_constituents_from_domains(con_context_t *ctxt, Linkage linkage,
 	numcon_subl = c - numcon_total;
 	/* numcon_subl = handle_islands(linkage, numcon_total, numcon_subl);  */
 
-	if (verbosity >= 2)
-		printf("Constituents added at first stage:\n");
-
-	for (c = numcon_total; c < numcon_total + numcon_subl; c++)
+	if (debug_level(D_CONST))
 	{
-		print_constituent(ctxt, linkage, c);
+		printf("Constituents added at first stage:\n");
+		for (c = numcon_total; c < numcon_total + numcon_subl; c++)
+		{
+			print_constituent(ctxt, linkage, c);
+		}
 	}
 
 	/* Opener case - generates S around main clause.
@@ -902,21 +915,21 @@ static int read_constituents_from_domains(con_context_t *ctxt, Linkage linkage,
 						(strcmp(linkage->word[ctxt->constituent[c2].right],
 								"RIGHT-WALL") == 0))
 					{
-						if (verbosity >= 2)
+						if (debug_level(D_CONST))
 							printf("Adjusting %d to fix comma overlap\n", c2);
 						adjust_for_right_comma(ctxt, linkage, c2);
 						adjustment_made = true;
 					}
 					else if (strcmp(linkage->word[ctxt->constituent[c].left], ",") == 0)
 					{
-						if (verbosity >= 2)
+						if (debug_level(D_CONST))
 							printf("Adjusting c %d to fix comma overlap\n", c);
 						adjust_for_left_comma(ctxt, linkage, c);
 						adjustment_made = true;
 					}
 					else
 					{
-						if (verbosity >= 2)
+						if (debug_level(D_CONST))
 						{
 							err_ctxt ec = { linkage->sent };
 							err_msg(&ec, Warn,
@@ -956,7 +969,7 @@ exprint_constituent_structure(con_context_t *ctxt,
 		rightdone[c] = false;
 	}
 
-	if (verbosity >= 2)
+	if (debug_level(D_CONST))
 		printf("\n");
 
 	/* Skip left wall; don't skip right wall, since it may
