@@ -594,7 +594,9 @@ dictionary_six_str(const char * lang,
 	dict->empty_word_defined = boolean_dictionary_lookup(dict, EMPTY_WORD_MARK);
 
 	dict->base_knowledge  = pp_knowledge_open(pp_name);
+	if (NULL == dict->base_knowledge) goto failure;
 	dict->hpsg_knowledge  = pp_knowledge_open(cons_name);
+	if (NULL == dict->hpsg_knowledge) goto failure;
 
 	dict->unknown_word_defined = boolean_dictionary_lookup(dict, UNKNOWN_WORD);
 	dict->use_unknown_word = true;
@@ -608,9 +610,7 @@ dictionary_six_str(const char * lang,
 	return dict;
 
 failure:
-	string_set_delete(dict->string_set);
-	if (dict->affix_table) xfree(dict->affix_table, sizeof(struct Dictionary_s));
-	xfree(dict, sizeof(struct Dictionary_s));
+	dictionary_delete(dict);
 	return NULL;
 }
 
