@@ -427,8 +427,8 @@ static utf8char get_character(Dictionary dict, int quote_mode)
 			uc[i] = c;
 			i++;
 		}
-		dict_error(dict, "Fatal Error: UTF8 char is too long");
-		exit(1);
+		dict_error(dict, "UTF8 char is too long");
+		return NULL;
 	}
 	uc[0] = 0x0;
 	return uc;
@@ -484,7 +484,12 @@ static bool link_advance(Dictionary dict)
 		return true;
 	}
 
-	do { c = get_character(dict, false); } while (lg_isspace(c[0]));
+	do
+	{
+		c = get_character(dict, false);
+		if (NULL == c) return false;
+	}
+	while (lg_isspace(c[0]));
 
 	quote_mode = false;
 
@@ -547,6 +552,7 @@ static bool link_advance(Dictionary dict)
 			}
 		}
 		c = get_character(dict, quote_mode);
+		if (NULL == c) return false;
 	}
 	return true;
 }
@@ -897,6 +903,17 @@ void free_lookup(Dict_node *llist)
 	}
 }
 
+void free_insert_list(Dict_node *ilist)
+{
+	Dict_node * n;
+	while (ilist != NULL)
+	{
+		n = ilist->left;
+		free_dict_node(ilist);
+		ilist = n;
+	}
+}
+
 static Dict_node * dictionary_lookup_wild(Dictionary dict, const char *s)
 {
 	bool lookup_idioms = test_enabled("lookup-idioms");
@@ -1909,7 +1926,7 @@ static bool read_entry(Dictionary dict)
 	return true;
 
 syntax_error:
-	free_lookup(dn);
+	free_insert_list(dn);
 	return false;
 }
 
