@@ -24,20 +24,24 @@
 
 /**
  * Print connector list to string.
- * This reverses the order of the connecters in the connector list,
+ * This reverses the order of the connectors in the connector list,
  * so that the resulting list is in the same order as it would appear
  * in the dictionary. The character 'dir' is appended to each connector.
  */
 static char * reversed_conlist_str(Connector* c, char dir, char* buf, size_t sz)
 {
 	char* p;
-	size_t len;
+	size_t len = 0;
 
 	if (NULL == c) return buf;
 	p = reversed_conlist_str(c->next, dir, buf, sz);
 
 	sz -= (p-buf);
-	len = lg_strlcpy(p, c->string, sz);
+
+	if (c->multi)
+		p[len++] = '@';
+
+	len += lg_strlcpy(p+len, c->string, sz-len);
 	if (3 < sz-len)
 	{
 		p[len++] = dir;
@@ -67,7 +71,7 @@ static void disjunct_str(Disjunct* dj, char* buf, size_t sz)
  * representation of the disjunct is needed for most of the corpus
  * statistics functions: this string, together with the subscripted
  * word, is used as a key to index the statistics information in the
- * database. 
+ * database.
  */
 void lg_compute_disjunct_strings(Linkage lkg)
 {
@@ -86,4 +90,3 @@ void lg_compute_disjunct_strings(Linkage lkg)
 		lkg->disjunct_list_str[w] = strdup(djstr);
 	}
 }
-
