@@ -33,15 +33,6 @@ static void verr_msg(err_ctxt *ec, severity sev, const char *fmt, va_list args)
 
 static void verr_msg(err_ctxt *ec, severity sev, const char *fmt, va_list args)
 {
-#ifdef _MSC_VER
-	char * tmp = alloca(strlen(fmt)+1);
-	char * tok = tmp;
-
-	strcpy(tmp, fmt);
-	while ((tok = strstr(tok, "%zu"))) { tok[1] = 'I'; tok++;}
-	fmt = tmp;
-#endif
-
 	/* As we are printing to stderr, make sure that stdout has been
 	 * written out first. */
 	fflush(stdout);
@@ -136,25 +127,47 @@ void prt_error(const char *fmt, ...)
 
 /**
  * Check whether the given feature is enabled. It is considered
- * enabled if it is found in the comma-separated list of features.
- * This list, if not empty, has a leading and a trailing comma.
- * Return NULL if not enabled, else non-NULL. If the feature appears
- * as "feature=val", return pointer to val.
+ * enabled if it is found in the comma delimited list of features.
+ * This list, if not empty, has a leading and a trailing commas.
+ * Return NULL if not enabled, else ",". If the feature appears
+ * as "feature:param", return a pointer to param.
+ * @param    list Comma delimited list of features (start/end commas too).
+ * @param    ... List of features to check.
+ * @return   If not enabled - NULL; Else "," or the feature param if exists.
  */
-const char *feature_enabled(const char * list, const char * feature)
+const char *feature_enabled(const char * list, ...)
 {
-	size_t len = strlen(feature);
-	char *buff = alloca(len + 2 + 1); /* leading comma + comma/eq + NUL */
 
-	buff[0] = ',';
-	strcpy(buff+1, feature);
-	strcat(buff, ",");
+	const char *feature;
+	va_list given_features;
+	va_start(given_features, list);
+
+	while (NULL != (feature = va_arg(given_features, char *)))
+	{
+		size_t len = strlen(feature);
+		char *buff = alloca(len + 2 + 1); /* leading comma + comma/colon + NUL */
+
+		/* The "feature" variable may contain a full/relative file path.
+		 * If so, extract the file name from it. On Windows first try the
+		 * native separator \, but also try /. */
+		const char *dir_sep = NULL;
+#ifdef _WIN32
+		dir_sep = strrchr(feature, '\\');
+#endif
+		if (NULL == dir_sep) dir_sep = strrchr(feature, '/');
+		if (NULL != dir_sep) feature = dir_sep + 1;
+
+		buff[0] = ',';
+		strcpy(buff+1, feature);
+		strcat(buff, ",");
+
+		if (NULL != strstr(list, buff)) return ",";
+		buff[len+1] = ':'; /* check for "feature:param" */
+		if (NULL != strstr(list, buff)) return strstr(list, buff) + len + 1;
+	}
+	va_end(given_features);
 
-	if (NULL != strstr(list, buff)) return ",";
-	buff[len+1] = ':'; /* check for "feature:..." */
-	if (NULL != strstr(list, buff)) return strstr(list, buff) + len + 1;
 	return NULL;
 }
 
-
 /* ============================================================ */
