@@ -94,6 +94,7 @@ void free_fast_matcher(fast_matcher_t *mchxt)
 	size_t w;
 	unsigned int i;
 
+	if (NULL == mchxt) return;
 	for (w = 0; w < mchxt->size; w++)
 	{
 		for (i = 0; i < mchxt->l_table_size[w]; i++)
@@ -129,7 +130,8 @@ static Match_node * add_to_right_table_list(Match_node * m, Match_node * l)
 	if (l == NULL) return m;
 
 	/* Insert m at head of list */
-	if ((m->d->right->word) <= (l->d->right->word)) {
+	if ((m->d->right->nearest_word) <= (l->d->right->nearest_word))
+	{
 		m->next = l;
 		return m;
 	}
@@ -137,7 +139,8 @@ static Match_node * add_to_right_table_list(Match_node * m, Match_node * l)
 	/* Walk list to insertion point */
 	prev = l;
 	p = prev->next;
-	while (p != NULL && ((m->d->right->word) > (p->d->right->word))) {
+	while (p != NULL && ((m->d->right->nearest_word) > (p->d->right->nearest_word)))
+	{
 		prev = p;
 		p = p->next;
 	}
@@ -160,7 +163,8 @@ static Match_node * add_to_left_table_list(Match_node * m, Match_node * l)
 	if (l == NULL) return m;
 
 	/* Insert m at head of list */
-	if ((m->d->left->word) >= (l->d->left->word)) {
+	if ((m->d->left->nearest_word) >= (l->d->left->nearest_word))
+	{
 		m->next = l;
 		return m;
 	}
@@ -168,7 +172,8 @@ static Match_node * add_to_left_table_list(Match_node * m, Match_node * l)
 	/* Walk list to insertion point */
 	prev = l;
 	p = prev->next;
-	while (p != NULL && ((m->d->left->word) < (p->d->left->word))) {
+	while (p != NULL && ((m->d->left->nearest_word) < (p->d->left->nearest_word)))
+	{
 		prev = p;
 		p = p->next;
 	}
@@ -462,13 +467,17 @@ static bool do_match_with_cache(Connector *a, Connector *b, match_cache *c_con)
 	/* The following uses a string-set compare - string_set_cmp() cannot
 	 * be used here because c_con->string may be NULL. */
 	match_stats(c_con->string == a->string ? NULL : a, NULL);
+#ifdef HAVE_MAYBE_UNINITIALIZED
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wmaybe-uninitialized"
+#endif /* HAVE_MAYBE_UNINITIALIZED */
 	/* The string field is initialized to NULL, and this is enough because
 	 * the connector string cannot be NULL, as it actually fetched a
 	 * non-empty match list. */
 	if (c_con->string == a->string) return c_con->match;
+#ifdef HAVE_MAYBE_UNINITIALIZED
 #pragma GCC diagnostic pop
+#endif /* HAVE_MAYBE_UNINITIALIZED */
 
 	/* No cache exists. Check if the connectors match and cache the result. */
 	c_con->match = match_lower_case(a, b) && match_hd(a, b);
@@ -525,7 +534,7 @@ form_match_list(fast_matcher_t *ctxt, int w,
 
 	for (mx = mr; mx != NULL; mx = mx->next)
 	{
-		if (mx->d->right->word > rw) break;
+		if (mx->d->right->nearest_word > rw) break;
 		mx->d->match_left = false;
 	}
 	mr_end = mx;
@@ -534,7 +543,7 @@ form_match_list(fast_matcher_t *ctxt, int w,
 	mc.string = NULL;
 	for (mx = ml; mx != NULL; mx = mx->next)
 	{
-		if (mx->d->left->word < lw) break;
+		if (mx->d->left->nearest_word < lw) break;
 		if ((w - lw) > mx->d->left->length_limit) continue;
 
 		mx->d->match_left = do_match_with_cache(mx->d->left, lc, &mc);
