@@ -44,6 +44,9 @@ link_public_api(const char *)
 link_public_api(const char *)
 	linkgrammar_get_dict_version(Dictionary);
 
+link_public_api(const char *)
+	linkgrammar_get_dict_locale(Dictionary);
+
 /**********************************************************************
  *
  * Functions to manipulate Dictionaries
@@ -116,8 +119,8 @@ link_public_api(void)
 link_public_api(bool)
      parse_options_get_islands_ok(Parse_Options opts);
 link_public_api(void)
-     parse_options_set_spell_guess(Parse_Options opts, bool spell_guess);
-link_public_api(bool)
+     parse_options_set_spell_guess(Parse_Options opts, int spell_guess);
+link_public_api(int)
      parse_options_get_spell_guess(Parse_Options opts);
 link_public_api(void)
      parse_options_set_short_length(Parse_Options opts, int short_length);
@@ -135,6 +138,10 @@ link_public_api(void)
      parse_options_set_cost_model_type(Parse_Options opts, Cost_Model_type cm);
 link_public_api(Cost_Model_type)
      parse_options_get_cost_model_type(Parse_Options opts);
+link_public_api(void)
+     parse_options_set_perform_pp_prune(Parse_Options opts, bool pp_prune);
+link_public_api(bool)
+     parse_options_get_perform_pp_prune(Parse_Options opts);
 link_public_api(void)
      parse_options_set_use_sat_parser(Parse_Options opts, bool use_sat_solver);
 link_public_api(bool)
@@ -242,8 +249,6 @@ link_public_api(Linkage)
      linkage_create(LinkageIdx linkage_num, Sentence sent, Parse_Options opts);
 link_public_api(void)
      linkage_delete(Linkage linkage);
-link_public_api(Sentence)
-     linkage_get_sentence(const Linkage linkage);
 link_public_api(size_t)
      linkage_get_num_words(const Linkage linkage);
 link_public_api(size_t)
@@ -314,21 +319,6 @@ link_public_api(const char *)
      linkage_get_violation_name(const Linkage linkage);
 
 
-/**********************************************************************
- *
- * Functions that allow special-purpose post-processing of linkages
- *
- ***********************************************************************/
-
-typedef struct Postprocessor_s PostProcessor;
-
-link_public_api(PostProcessor *)
-     post_process_open(const char *path);
-link_public_api(void)
-     post_process_close(PostProcessor *);
-link_public_api(void)
-     linkage_post_process(Linkage, PostProcessor *);
-
 /**********************************************************************
  *
  * Internal functions -- do not use these in new code!
@@ -346,7 +336,6 @@ link_public_api(void)
 link_public_api(bool)
      lg_expand_disjunct_list(Sentence sent);
 
-
 /**********************************************************************
  *
  * Internal functions -- do not use these in new code!
@@ -371,9 +360,8 @@ link_public_api(void)
 
 /*******************************************************
  *
- * Obsolete functions -- do not use these in new code!
- * XXX TODO: These will all be removed, once the Russian dicts support
- * conjunctions; Russian is the last remaining user of these functions.
+ * Macros for marking obsolete functions -- but there aren't any,
+ * just right now.
  *
  ********************************************************/
 
@@ -389,86 +377,21 @@ link_public_api(void)
  #define MS_DEPRECATED
 #endif
 
-#ifdef USE_FAT_LINKAGES
-#pragma message("WARNING: Support for FAT linkages is going away!")
-#endif /* USE_FAT_LINKAGES */
-
-/* When fat links are gone, there's no union to compute. */
-MS_DEPRECATED link_public_api(int)
-     linkage_compute_union(Linkage linkage) GNUC_DEPRECATED;
-
-/* When fat links go away, all linkages are thin */
-MS_DEPRECATED link_public_api(int)
-     linkage_is_fat(const Linkage linkage) GNUC_DEPRECATED;
-
-/* When fat links go away, the number of sublinkages will always be one */
-MS_DEPRECATED link_public_api(int)
-     linkage_get_num_sublinkages(const Linkage linkage) GNUC_DEPRECATED;
-
-/* When fat links go away, the only valid sublinkage will be zero. */
-MS_DEPRECATED link_public_api(bool)
-     linkage_set_current_sublinkage(Linkage linkage, LinkageIdx index) GNUC_DEPRECATED;
-
-/* When fat links go away, the only valid sublinkage will be zero. */
-MS_DEPRECATED link_public_api(int)
-     linkage_get_current_sublinkage(const Linkage linkage) GNUC_DEPRECATED;
-
-/* When fat links go away, all linkages are proper. */
-MS_DEPRECATED link_public_api(int)
-     linkage_is_improper(const Linkage linkage) GNUC_DEPRECATED;
-
-/* All linkages are canonical when there are no fat links. */
-MS_DEPRECATED link_public_api(int)
-     linkage_is_canonical(const Linkage linkage) GNUC_DEPRECATED;
-
-/* Not possible without fat links */
-MS_DEPRECATED link_public_api(int)
-     linkage_has_inconsistent_domains(const Linkage linkage) GNUC_DEPRECATED;
-
-/* and cost is always zero without fat links */
-MS_DEPRECATED link_public_api(int)
-     linkage_and_cost(const Linkage linkage) GNUC_DEPRECATED;
-
-/* All linkages are thin, when none are fat */
-MS_DEPRECATED link_public_api(int)
-     sentence_num_thin_linkages(Sentence sent) GNUC_DEPRECATED;
-
-/* Bogus/pointless when no fat links */
-MS_DEPRECATED link_public_api(int)
-     sentence_contains_conjunction(Sentence sent) GNUC_DEPRECATED;
-
-/* and cost is always zero without fat links */
-MS_DEPRECATED link_public_api(int)
-     sentence_and_cost(Sentence sent, LinkageIdx linkage_num) GNUC_DEPRECATED;
-
-/* Fat linkages will be going away "real soon now" */
-MS_DEPRECATED link_public_api(void)
-     parse_options_set_use_fat_links(Parse_Options opts, int use_fat_links) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(int)
-     parse_options_get_use_fat_links(Parse_Options opts) GNUC_DEPRECATED;
-
 /**********************************************************************
  *
- * Constituent node
+ * Functions that allow special-purpose post-processing of linkages
  *
  ***********************************************************************/
 
-typedef struct CNode_s CNode;
+/** Do not use in new code! */
+typedef struct Postprocessor_s PostProcessor;
 
-MS_DEPRECATED link_public_api(CNode *)
-     linkage_constituent_tree(Linkage linkage) GNUC_DEPRECATED;
+MS_DEPRECATED link_public_api(PostProcessor *)
+     post_process_open(const char *path) GNUC_DEPRECATED;
 MS_DEPRECATED link_public_api(void)
-     linkage_free_constituent_tree(CNode * n) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(const char *)
-     linkage_constituent_node_get_label(const CNode *n) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(CNode *)
-     linkage_constituent_node_get_child(const CNode *n) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(CNode *)
-     linkage_constituent_node_get_next(const CNode *n) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(int)
-     linkage_constituent_node_get_start(const CNode *n) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(int)
-     linkage_constituent_node_get_end(const CNode *n) GNUC_DEPRECATED;
+     post_process_close(PostProcessor *) GNUC_DEPRECATED;
+MS_DEPRECATED link_public_api(void)
+     linkage_post_process(Linkage, PostProcessor *) GNUC_DEPRECATED;
 
 LINK_END_DECLS
 
