@@ -22,8 +22,14 @@
 #include "utilities.h"  /* For Win32 compatibility */
 
 #define ASPELL_LANG_KEY  "lang"
+/* FIXME: Move to a definition file (affix file?). */
 static const char *spellcheck_lang_mapping[] = {
-	"en" /* link-grammar language */, "en_US" /* Aspell language key */
+/* link-grammar language , Aspell language key */
+	"en", "en_US",
+	"ru", "ru_RU",
+	"he", "he_IL",
+	"de", "de_DE",
+	"lt", "lt_LT",
 };
 
 struct linkgrammar_aspell {
@@ -140,7 +146,7 @@ int spellcheck_suggest(void * chk, char ***sug, const char * word)
 	return 0;
 }
 
-void spellcheck_free_suggest(char **sug, int size)
+void spellcheck_free_suggest(void *chk, char **sug, int size)
 {
 	int i = 0;
 	for (i = 0; i < size; ++i) {
