@@ -31,12 +31,21 @@ static const char *hunspell_dict_dirs[] = {
 	"/usr/share/hunspell",
 	"/usr/local/share/myspell",
 	"/usr/local/share/hunspell",
-	HUNSPELL_DICT_DIR	
+	HUNSPELL_DICT_DIR
 };
 
 static const char *spellcheck_lang_mapping[] = {
-	"en" /* link-grammar language */, "en-US" /* hunspell filename */,
-	"en" /* link-grammar language */, "en_US" /* hunspell filename */
+/* link-grammar language, Hunspell filename */
+	"en", "en-US",
+	"en", "en_US",
+	"ru", "ru-RU",
+	"ru", "ru_RU",
+	"he", "he-IL",
+	"he", "he_IL",
+	"de", "de-DE",
+	"de", "de_DE",
+	"lt", "lt-LT",
+	"lt", "lt_LT",
 };
 
 #define FPATHLEN 256
@@ -122,9 +131,9 @@ int spellcheck_suggest(void * chk, char ***sug, const char * word)
 	return Hunspell_suggest((Hunhandle *)chk, sug, word);
 }
 
-void spellcheck_free_suggest(char **sug, int size)
+void spellcheck_free_suggest(void *chk, char **sug, int size)
 {
-	free(sug);
+	Hunspell_free_list((Hunhandle *)chk, &sug, size);
 }
 
 #endif /* #ifdef HAVE_HUNSPELL */
