@@ -32,6 +32,7 @@
 #endif /* HAVE_LOCALE_T_IN_XLOCALE_H */
 
 #include "error.h"
+#include "lg_assert.h"
 
 #ifdef HAVE_ALLOCA_H
 # include <alloca.h>
@@ -187,22 +188,6 @@ typedef int locale_t;
 #define STR(x) #x
 #define STRINGIFY(x) STR(x)
 
-#define FILELINE __FILE__ ":" STRINGIFY(__LINE__)
-
-#ifdef _WIN32
-#define DEBUG_TRAP (*((volatile int*) 0x0) = 42)
-#else
-#define DEBUG_TRAP __builtin_trap()
-#endif
-
-#define assert(ex, ...) {                                                   \
-	if (!(ex)) {                                                             \
-		prt_error("\nAssertion (" #ex ") failed at " FILELINE ": " __VA_ARGS__);  \
-		fprintf(stderr, "\n");                                                \
-		DEBUG_TRAP;  /* leave stack trace in debugger */                      \
-	}                                                                        \
-}
-
 #if defined(__UCLIBC__)
 #define fmaxf(a,b) ((a) > (b) ? (a) : (b))
 #endif
@@ -214,9 +199,29 @@ typedef int locale_t;
 #define MAX(X,Y)  ( ((X) > (Y)) ? (X) : (Y))
 #endif
 
+/* From ccan array_size.h and build_assert.h, which are under a CC0 license */
+#define BUILD_ASSERT_OR_ZERO(cond) (sizeof(char [1 - 2*!(cond)]) - 1)
 #if !defined(ARRAY_SIZE)
-#define ARRAY_SIZE(a) (sizeof(a) / sizeof((a)[0]))
+/**
+ * ARRAY_SIZE - get the number of elements in a visible array
+ * @arr: the array whose size you want.
+ *
+ * This does not work on pointers, or arrays declared as [], or
+ * function parameters.  With correct compiler support, such usage
+ * will cause a build error (see build_assert).
+ */
+#define ARRAY_SIZE(arr) (sizeof(arr) / sizeof((arr)[0]) + _array_size_chk(arr))
+
+#if HAVE_BUILTIN_TYPES_COMPATIBLE_P && HAVE_TYPEOF
+/* Two gcc extensions.
+ * &a[0] degrades to a pointer: a different type from an array */
+#define _array_size_chk(arr)
+	BUILD_ASSERT_OR_ZERO(!__builtin_types_compatible_p(typeof(arr), \
+							typeof(&(arr)[0])))
+#else
+#define _array_size_chk(arr) 0
 #endif
+#endif /* !defined(ARRAY_SIZE) */
 
 /* Optimizations etc. that only gcc understands */
 #if __GNUC__ > 2
